@@ -2,10 +2,13 @@
 LayoutLMDocumentQA is a multimodal good for
 visual question answering on real world docs lik invoice, pdfs, etc
 """
+
 from transformers import pipeline
 
+from swarms.models.base_multimodal_model import BaseMultiModalModel
 
-class LayoutLMDocumentQA:
+
+class LayoutLMDocumentQA(BaseMultiModalModel):
     """
     LayoutLMDocumentQA for document question answering:
 
@@ -25,11 +28,24 @@ class LayoutLMDocumentQA:
         self,
         model_name: str = "impira/layoutlm-document-qa",
         task_type: str = "document-question-answering",
+        *args,
+        **kwargs,
     ):
-        self.pipeline = pipeline(self.task_type, model=self.model_name)
+        super().__init__(*args, **kwargs)
+        self.model_name = model_name
+        self.task_type = task_type
+        self.pipeline = pipeline(task_type, model=model_name)
 
-    def __call__(self, task: str, img_path: str):
-        """Call for model"""
+    def __call__(self, task: str, img_path: str, *args, **kwargs):
+        """Call the LayoutLMDocumentQA model
+
+        Args:
+            task (str): _description_
+            img_path (str): _description_
+
+        Returns:
+            _type_: _description_
+        """
         out = self.pipeline(img_path, task)
         out = str(out)
         return out
