@@ -1,9 +1,7 @@
-from rich import print as rich_print
-from rich.markdown import Markdown
-from rich.rule import Rule
+from termcolor import colored
 
 
-def display_markdown_message(message):
+def display_markdown_message(message: str, color: str = "cyan"):
     """
     Display markdown message. Works with multiline strings with lots of indentation.
     Will automatically make single line > tags beautiful.
@@ -12,12 +10,15 @@ def display_markdown_message(message):
     for line in message.split("\n"):
         line = line.strip()
         if line == "":
-            print("")
+            print()
         elif line == "---":
-            rich_print(Rule(style="white"))
+            print(colored("-" * 50, color))
         else:
-            rich_print(Markdown(line))
+            print(colored(line, color))
 
     if "\n" not in message and message.startswith(">"):
         # Aesthetic choice. For these tags, they need a space below them
-        print("")
+        print()
+
+
+# display_markdown_message("I love you and you are beautiful.", "cyan")
